import importlib

import httpx
from rich import print


def check_latest_amsdal_version() -> None:
    session = httpx.Client()

    modules_to_update: list[str] = []

    for amsdal_module in [
        'amsdal_utils',
        'amsdal_data',
        'amsdal_models',
        'amsdal',
        'amsdal_server',
        'amsdal_cli',
    ]:
        try:
            module = importlib.import_module(f'{amsdal_module}.__about__')
            current_version = module.__version__
            response = session.get(f'https://pypi.org/pypi/{amsdal_module}/json')
            latest_version = response.json()['info']['version']

            if current_version == latest_version:
                continue

            print(
                f'You are using {amsdal_module} version [orange3]{current_version}[/orange3], '
                f'however version [orange3]{latest_version}[/orange3] is available.'
            )

            modules_to_update.append(amsdal_module)

        except ImportError:
            continue

    if modules_to_update:
        upgrade_command = 'pip install --upgrade ' + ' '.join(modules_to_update)
        print(f"You should consider upgrading via the [dark_green]'{upgrade_command}'[/dark_green] command.")
